@@ -25,8 +25,15 @@
 
 #ifdef HAVE_LIBFLAC
 
+#include "ui_encoderflacconfig.h"
+
 #include <audiocdencoder.h>
 
+class EncoderFLACConfig : public QWidget, public Ui::EncoderFLACConfig {
+public:
+  explicit EncoderFLACConfig(QWidget *parent = 0) : QWidget( parent ) { setupUi( this ); }
+};
+
 /**
  * FLAC encoder.
  * This encoder is only enabled when HAVE_LIBFLAC is set.
@@ -48,6 +55,7 @@ public:
   virtual long readInit(long size);
   virtual long read(int16_t * buf, int frames);
   virtual long readCleanup();
+  virtual QWidget* getConfigureWidget(KConfigSkeleton** manager) const;
 
   class Private;
 private:
